###################################################
### chunk number 1: options
###################################################

options(width=80,continue=" ")



###################################################
### chunk number 2: libraryCHNOSZ
###################################################

library(CHNOSZ)



###################################################
### chunk number 3: proteins
###################################################

# ribulose phosphate carboxylase

# in order of increasing growth temperature

rubisco <- c("RBL_BRAJA","A6YF84_9PROT","A1E8R4_9CHLO","A8C9T6_9MYCO","A3EQE1_9BACT","A5CKC7_9CHRO",

  "RBL_SYNJA","Q6JAI0_9RHOD","RBL_METJA","A3DND9_STAMF","A1RZJ5_THEPD","RBL_PYRHO")

rubisco.organisms <- c("a-proteobacterium-R","b-proteobacterium","Bracteacoccus","Mycobacterium",

  "Leptospirillum","Cyanobium","Synechococcus","Cyanidiales",

  "Methanococcus-R","Desulfurococcus","Thermofilum","Pyrococcus")

accoaco <- c("Q9F7M8_PRB01","ACCA_DEIRA","A6CDM2_9PLAN","A4AGS7_9ACTN","ACCA_CAUCR","A1VC70_DESVV",

  "A6VIX9_METM7","Q2JSS7_SYNJA","A0GZU2_9CHLR","A7WGI1_9AQUI","Q05KD0_HYDTH","ACCA_AQUAE")

accoaco.organisms <- c("g-proteobacterium","Deinococcus","Planctomyces","Actinobacterium",

  "a-proteobacterium-A","d-proteobacterium","Methanococcus-A","Synechococcus",

  "Chloroflexus","Hydrogenobaculum","Hydrogenobacter","Aquifex")



###################################################
### chunk number 4: basis
###################################################

basis(c("CO2","H2O","NH3","H2","H2S","H+"),

  c("aq","liq","aq","aq","aq","aq"),c(-3,0,-4,-6,-7,-7))



###################################################
### chunk number 5: getlogaH2
###################################################

get.logaH2 <- function(T) return(-11+T*3/40)



###################################################
### chunk number 6: plot.it
###################################################

# function to make various equilibrium activity diagrams

# for the carboxylases

plot.it <- function(vars='H2',lims=c(-15,0),

  do.plot=TRUE,dolegend=NULL,ylim=c(-6,-2),

  rect=NULL,drawme=c("rubisco","accoaco")) {

  proteins <- c('rubisco','accoaco')

  r.p <- get(proteins[1])

  a.p <- get(proteins[2])

  my.p <- list(r.p,a.p)

  species(c(r.p,a.p))

  if(is.list(lims)) myargs <- lims else myargs <- list(lims)

  names(myargs) <- vars

  a <- do.call(affinity,myargs)

  # colors: reds for thermo, blue for meso

  r.cols <- c(rep("blue",6),rep("red",6))

  r.lty <- rep(3,12)

  r.lwd <- rep(2,length(r.p))

  a.cols <- c(rep("blue",6),rep("red",6))

  a.lty <- rep(1,12)

  a.lwd <- rep(2,length(a.p))

  if(!"rubisco" %in% drawme) r.lty <- rep(0,length(r.p))

  if(!"accoaco" %in% drawme) {

    r.lty <- a.lty

    a.lty <- rep(0,length(a.p))

  }

  my.cols <- list(r.cols,a.cols)

  my.lty <- list(r.lty,a.lty)

  my.lwd <- list(r.lwd,a.lwd)

  # setup the plot

  if(do.plot) {

    # leave the top y-axis open if we are plotting as a 

    # function of two variables

    if(length(vars)==1) {

      side <- 1:4

      xline <- 1

    } else {

      side <- c(1,2,4)

      xline <- 2.5

    }     

    thermo.plot.new(xlim=range(myargs[[1]]),ylim=ylim,

      xlab=axis.label(vars[1]),ylab=expression(log~italic(a)),

      yline=2,mar=c(2.5,3,xline,1),side=side)

    if(!is.null(rect)) rect(rect[1],rect[2],rect[3],rect[4],col="grey80",border=NA)

  }

  # calculate equilibrium activities

  # use unit total activity of amino acid residue

  d <- diagram(a,residue=TRUE,col=c(r.cols,a.cols),lty=c(r.lty,a.lty),

    legend.x=NULL,do.plot=do.plot,cex=2,lwd=c(r.lwd,a.lwd),

    mam=FALSE,add=TRUE,logact=0)

  # legends and possibly second y-axis

  if(do.plot) {

    if(!is.null(dolegend)) {

      if(length(dolegend)==2) {

        which.p <- match(dolegend[1],proteins)

        legend('topleft',legend=c(dolegend[1],my.p[[which.p]]),

          lty=c(NA,my.lty[[which.p]]),col=c(NA,my.cols[[which.p]]),

          lwd=c(NA,my.lwd[[which.p]]),cex=0.6,bg='white')

      }

      ld <- length(dolegend)

      which.p <- match(dolegend[ld],proteins)

      legend('topright',legend=c(dolegend[ld],my.p[[which.p]]),

        lty=c(NA,my.lty[[which.p]]),col=c(NA,my.cols[[which.p]]),

        lwd=c(NA,my.lwd[[which.p]]),cex=0.6,bg='white')

    }

    # add a second y-axis

    #if(length(vars)==2) secondaxis(vars[2],range(lims[[2]]))

  }

  return(invisible(list(a=a,d=d)))

}



###################################################
### chunk number 7: plot.it.args
###################################################

print(args(plot.it))



###################################################
### chunk number 8: limits
###################################################

Tlim <- c(0,140)

H2lim <- c(-10,-2)

Tval <- seq(Tlim[1],Tlim[2],length.out=128)

H2val <- seq(H2lim[1],H2lim[2],length.out=128)



###################################################
### chunk number 9: itemp
###################################################

ilowT <- c(1:6,13:18)

ihighT <- c(7:12,19:24)



###################################################
### chunk number 10: loga.ref
###################################################

loga.ref <- -5



###################################################
### chunk number 11: carboxylase1
###################################################

# Figure 1: relative abundances and richness f(T,logaH2)

par(mfrow=c(1,2))

par(cex=1,lwd=1,mar=c(2.5,3,1,1))

# Figure 1a: relative abundances as a function of temperature

Tout <- plot.it('T',Tlim,dolegend='accoaco',rect=c(Tlim[1],-6,Tlim[2],loga.ref))

label.plot('a',xfrac=0.1)

# Figure 1b: relative abundances as a function of logaH2

H2out <- plot.it('H2',H2lim,dolegend='rubisco',rect=c(H2lim[1],-6,H2lim[2],loga.ref))

label.plot('b',xfrac=0.1)



###################################################
### chunk number 12: carboxylase2
###################################################

# Figure 2: richness plot as a function of temperature

par(mfrow=c(1,2))

par(cex=1,lwd=1,mar=c(2.5,3,1,1))

revisit(Tout$d,"richness",loga.ref=loga.ref,yline=2,plot.ext=FALSE)

revisit(Tout$d,"richness",loga.ref=loga.ref,ispecies=ilowT,col="blue",add=TRUE,plot.ext=FALSE)

revisit(Tout$d,"richness",loga.ref=loga.ref,ispecies=ihighT,col="red",add=TRUE,plot.ext=FALSE)

label.plot("a",xfrac=0.1)

# Figure 2b: richness plot as a function of logaH2

revisit(H2out$d,"richness",loga.ref=loga.ref,yline=2,plot.ext=FALSE)

revisit(H2out$d,"richness",loga.ref=loga.ref,ispecies=ilowT,col="blue",add=TRUE,plot.ext=FALSE)

revisit(H2out$d,"richness",loga.ref=loga.ref,ispecies=ihighT,col="red",add=TRUE,plot.ext=FALSE)

label.plot("b",xfrac=0.1)



###################################################
### chunk number 13: carboxylase3
###################################################

# Figure 3: logaH2-T protein stability diagram 

par(cex=1.5,lwd=1.5)

# first get the logaH2 values

logaH2.line <- get.logaH2(Tval)

# calculate affinities; proteins were loaded previously

a <- affinity(T=Tlim,H2=H2lim)

# plot the protein stabilities

col <- rep(c(rep("blue",6),rep("red",6)),2)

diagram(a,residue=TRUE,col.names=col,color=NULL)

# as well as water reduction line, taking fH2=Psat

s <- subcrt(c("H2","H2"),c("gas","aq"),c(-1,1),T=Tval)

logaH2 <- s$out$logK + log10(s$out$P)

lines(Tval,logaH2,lwd=4,lty=2,col="forestgreen")

# and show our logaH2 function

lines(Tval,logaH2.line,lwd=4,lty=3,col="forestgreen")

legend("bottomright",legend=c("H2O reduction","logaH2 = -11 + T*3/40"),

  lty=c(2,3),lwd=3,col="forestgreen")



###################################################
### chunk number 14: carboxylase4
###################################################

    # Figure 4: relative abundances with logaH2 as linear f(T)

    par(mfrow=c(2,1))

    # Figure 3a: relative abundances with logaH2 as linear f(T)

    mylogaH2 <- get.logaH2(Tval)

    out <- plot.it(c("T","H2"),list(Tval,mylogaH2),rect=c(Tlim[1],-6,Tlim[2],loga.ref))

    label.plot("a",xfrac=0.1)

    # Figure 3b: richness with linear logaH2

    revisit(out$d,"richness",loga.ref=loga.ref,yline=2,side=c(1,2,4),plot.ext=FALSE)

    revisit(out$d,"richness",loga.ref=loga.ref,ispecies=ilowT,

      col="blue",add=TRUE,plot.ext=FALSE)

    revisit(out$d,"richness",loga.ref=loga.ref,ispecies=ihighT,

      col="red",add=TRUE,plot.ext=FALSE)

    label.plot("b",xfrac=0.1)

    # to plot a second x-axis  

    usr <- par('usr')

    usr[1:2] <- range(mylogaH2)

    opar <- par(usr=usr)

    thermo.axis(axis.label("H2"),side=3,line=par("mgp")[1],cex=par("cex"))



###################################################
### chunk number 15: plot.rank
###################################################

plot.rank <- function(T=25,ntop=5,pretext=NULL,lcex=1) {

  proteins <- c('rubisco','accoaco')

  organisms <- c(rubisco.organisms,accoaco.organisms)

  # new scheme 20090611: red for hot, blue for cold

  # open for rubisco, filled for accoaco

  col <- rep(c(rep("blue",6),rep("red",6)),2)

  pch <- c(rep(c(0:2,5:7),2),rep(c(15:20),2))

  H2 <- get.logaH2(T)

  if(length(T)==1) {

    basis("H2",H2)

    a <- affinity(T=T)

  } else a <- affinity(T=T,H2=H2)

  d <- diagram(a,residue=TRUE,legend.x=NULL,ylim=c(-6,-2),do.plot=FALSE)

  # for each point make a rank plot

  rank <- 1:length(d$logact)

  # put some lead-in and lead-out frames

  res <- length(T)

  ido <- c(rep(1,15),1:res,rep(res,20))

  if(res==1) ido <- 1

  for(i in ido) {

    loga <- numeric()

    for(j in 1:length(d$logact)) loga <- c(loga,d$logact[[j]][i])

    if(i > 4) myrank4 <- myrank3

    if(i > 3) myrank3 <- myrank2

    if(i > 2) myrank2 <- myrank1

    if(i > 1) myrank1 <- myrank

    order <- order(loga,decreasing=TRUE)

    myrank <- rank(loga)

    cex <- rep(1.2,24)

    # show changed by increasing point size

    # any points that changed on the step before the step 

    # before the step before?

    if(i > 4) {

      ichanged <- myrank3 != myrank4

      cex[ichanged[order]] <- cex[ichanged[order]] + 0.1

    }

    # any points that changed on the step before the step before?

    if(i > 3) {

      ichanged <- myrank2 != myrank3

      cex[ichanged[order]] <- cex[ichanged[order]] + 0.2

    }

   # any points that changed on the step before?

    if(i > 2) {

      ichanged <- myrank1 != myrank2

      cex[ichanged[order]] <- cex[ichanged[order]] + 0.3

    }

    # any points that changed on this step?

    if(i > 1) {

      ichanged <- myrank != myrank1

      cex[ichanged[order]] <- cex[ichanged[order]] + 0.4

    }

    plot(rank,loga[order],col=col[order],pch=pch[order],

      ylab=expression(log~italic(a)),cex=cex,cex.main=1,cex.lab=1,cex.axis=1)

    myT <- format(round(T,1))[i]

    myH2 <- format(round(H2,2))[i]

    if(!is.null(pretext)) title(main=substitute(list(Z~X~degree*C,

      log*italic(a)[paste(H2)]==Y),list(X=myT,Y=myH2,Z=pretext)))

    else title(main=substitute(list(X~degree*C, log*italic(a)[paste(H2)]==Y),

      list(X=myT,Y=myH2)))

    legend("topright",legend=c(paste("top",ntop),organisms[order[1:ntop]]),

      pch=c(NA,pch[order[1:ntop]]),col=c(NA,col[order[1:ntop]]),

      pt.cex=c(NA,cex[1:ntop]),cex=lcex)

    order <- order(loga)

    legend("bottomleft",legend=c(paste("low",ntop),organisms[order[ntop:1]]),

      pch=c(NA,pch[order[ntop:1]]),col=c(NA,col[order[ntop:1]]),

      pt.cex=c(NA,cex[24:(24-ntop+1)]),cex=lcex)

  }

}





###################################################
### chunk number 16: carboxylase5
###################################################

plot.rank(T=25)



###################################################
### chunk number 17: carboxylase6
###################################################

plot.rank(T=100)



###################################################
### chunk number 18: makepng eval=FALSE
###################################################
## 
## png(filename="Rplot%03d.png",width=420,height=320)
## 
## plot.rank(T=25:125,lcex=0.8)
## 
## dev.off()
## 


